@@ -24,7 +24,7 @@ class AttributeFilledMock:
         return self
 
     def __call__(self, *args, **kargs):
-        warn('This call does nothing as PyRosetta is not installed', RuntimeWarning)
+        warn('This call does nothing as PyRosetta is not installed', category=RuntimeWarning)
         return self
 
 # ======================================================================================================================
@@ -32,7 +32,7 @@ class AttributeFilledMock:
 if util.find_spec('pyrosetta'):
     import pyrosetta
 else:
-    warn('PyRosetta is not installed. A mock object is loaded. Any calls will fail.')
+    warn('PyRosetta is not installed. A mock object is loaded. Any calls will fail.', category=RuntimeWarning)
     pyrosetta = AttributeFilledMock()
     sys.modules['pyrosetta'] = pyrosetta
 
