@@ -3,8 +3,8 @@ from io import StringIO
 from typing import (Dict, TYPE_CHECKING)
 import sys
 
-if TYPE_CHECKING or 'sphinx' in sys.modules:
-    import nglview as nv
+import nglview as nv
+from ..display import MolNGLWidget
 
 from IPython.display import display
 from rdkit import Chem
@@ -60,16 +60,29 @@ class WaltonArt(WaltonBase):
         with the compounds and the merged if present.
         The colours will be those in the ``Chem.Mol``'s property ``_color``.
         """
-        import nglview as nv
-        view = nv.NGLWidget()
+        view = MolNGLWidget()
         for mol in self.mols + [self.merged]:
             if not mol:  # self.merged is empty
                 continue
-            fh = StringIO(Chem.MolToPDBBlock(mol))
-            comp: nv.component.ComponentViewer = view.add_component(fh, ext='pdb')  # noqa it's there.
-            comp.update_ball_and_stick(colorValue=self._get_mol_color(mol), multipleBond=True)
+            view.add_mol(mol)
         return view
 
+    def refresh_nglview(self, view: nv.NGLWidget, *others:Chem.Mol) -> None:
+        """
+        In Walton altering hits manually does not have an effect on the NGLWidget,
+        but altering hits has no bad juju unlike Monster where altering the `.mols` can have a detrimental effect,
+        due to the lack of the sanitisation from the `monster.fix_mols(mols)` call.
+
+        :param view:
+        :return:
+        """
+        view.remove_all_components()
+        for mol in self.mols + [self.merged] + list(others):
+            if not mol:  # self.merged is empty
+                continue
+            view.add_mol(mol)
+
+
     def show3d(self) -> None:
         """
         Shows the structures in 2d and 3d.
